==> kvalifika_sdk-0.10.0.tar.gz: lib/kvalifika_sdk.dart <==
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class KvalifikaSdk extends StatefulWidget {
  static const MethodChannel _channel = const MethodChannel('kvalifika_sdk');

  /// Calls this function when SDK initializes
  final Function onInitialize;

  /// Calls this function with session id when verification started
  final Function(String sessionId) onStart;

  /// Calls this function with session id  when verification finished
  final Function(String sessionId) onFinish;

  /// Calls this function with error and message if there is error. Maybe user cancelled verification or there is some internal error
  final Function(KvalifikaSdkError error, String message) onError;

  final Widget Function(BuildContext context, KvalifikaSdk sdk) builder;

  /// Kvalifika App Id
  final String appId;

  /// Sets Language which SDK will use
  final KvalifikaSdkLocale locale;

  /// Pass filename. Displays custom logo
  final String? logo;

  /// Pass filename. Displays custom document icon
  final String? documentIcon;

  /// Uses custom cancel icon at top left corner
  final String? cancelIcon;

  /// Uses custom active flash icon at top right corner when scanning document
  final String? activeFlashIcon;

  /// Uses custom inactive flash icon at top right corner when scanning document
  final String? inactiveFlashIcon;

  /// Runs SDK in development mode. This is only for developers
  final bool? development;

  KvalifikaSdk({
    required this.builder,
    required this.appId,
    required this.onInitialize,
    required this.onStart,
    required this.onFinish,
    required this.onError,
    this.locale = KvalifikaSdkLocale.EN,
    this.logo = "",
    this.documentIcon = "",
    this.cancelIcon = "",
    this.activeFlashIcon = "",
    this.inactiveFlashIcon = "",
    this.development = false,
  });

  /// Starts Kvalifika verification session
  void startSession() async {
    await _channel.invokeMethod('sdkStartSession');
  }

  @override
  _KvalifikaSdkState createState() {
    _channel.setMethodCallHandler((MethodCall call) async {
      if (call.method == "sdkOnInitialize") {
        this.onInitialize();
      } else if (call.method == "sdkOnStart") {
        this.onStart(call.arguments);
      } else if (call.method == "sdkOnFinish") {
        this.onFinish(call.arguments);
      } else if (call.method == "sdkOnError") {
        List args = call.arguments.split("___");
        String errorName = args[0];
        String message = args[1];

        switch (errorName) {
          case 'INVALID_APP_ID':
            this.onError(KvalifikaSdkError.INVALID_APP_ID, message);
            break;
          case 'USER_CANCELLED':
            this.onError(KvalifikaSdkError.USER_CANCELLED, message);
            break;
          case 'TIMEOUT':
            this.onError(KvalifikaSdkError.TIMEOUT, message);
            break;
          case 'SESSION_UNSUCCESSFUL':
            this.onError(KvalifikaSdkError.SESSION_UNSUCCESSFUL, message);
            break;
          case 'ID_UNSUCCESSFUL':
            this.onError(KvalifikaSdkError.ID_UNSUCCESSFUL, message);
            break;
          case 'CAMERA_PERMISSION_DENIED':
            this.onError(KvalifikaSdkError.CAMERA_PERMISSION_DENIED, message);
            break;
          case 'LANDSCAPE_MODE_NOT_ALLOWED':
            this.onError(KvalifikaSdkError.LANDSCAPE_MODE_NOT_ALLOWED, message);
            break;
          case 'REVERSE_PORTRAIT_NOT_ALLOWED':
            this.onError(
                KvalifikaSdkError.REVERSE_PORTRAIT_NOT_ALLOWED, message);
            break;
          case 'FACE_IMAGES_UPLOAD_FAILED':
            this.onError(KvalifikaSdkError.FACE_IMAGES_UPLOAD_FAILED, message);
            break;
          case 'DOCUMENT_IMAGES_UPLOAD_FAILED':
            this.onError(
                KvalifikaSdkError.DOCUMENT_IMAGES_UPLOAD_FAILED, message);
            break;
          case 'COMPARE_IMAGES_FAILED':
            this.onError(KvalifikaSdkError.COMPARE_IMAGES_FAILED, message);
            break;
          case 'UNKNOWN_INTERNAL_ERROR':
            this.onError(KvalifikaSdkError.UNKNOWN_INTERNAL_ERROR, message);
            break;
          default:
            this.onError(KvalifikaSdkError.UNKNOWN_INTERNAL_ERROR, message);
            break;
        }
      }

      return null;
    });

    _channel.invokeMethod('sdkInitialize', {
      'appId': appId,
      'locale': locale.toString().split('.')[1],
      'logo': logo,
      'documentIcon': documentIcon,
      'cancelIcon': cancelIcon,
      'activeFlashIcon': activeFlashIcon,
      'inactiveFlashIcon': inactiveFlashIcon,
      'development': development,
    });

    return _KvalifikaSdkState();
  }
}

class _KvalifikaSdkState extends State<KvalifikaSdk> {
  @override
  Widget build(BuildContext context) {
    return this.widget.builder(context, this.widget);
  }
}

enum KvalifikaSdkError {
  INVALID_APP_ID,
  USER_CANCELLED,
  TIMEOUT,
  SESSION_UNSUCCESSFUL,
  ID_UNSUCCESSFUL,
  CAMERA_PERMISSION_DENIED,
  LANDSCAPE_MODE_NOT_ALLOWED,
  REVERSE_PORTRAIT_NOT_ALLOWED,
  FACE_IMAGES_UPLOAD_FAILED,
  DOCUMENT_IMAGES_UPLOAD_FAILED,
  COMPARE_IMAGES_FAILED,
  UNKNOWN_INTERNAL_ERROR,
}

enum KvalifikaSdkLocale {
  EN,
  GE,
}

==> kvalifika_sdk-0.11.0.tar.gz: lib/kvalifika_sdk.dart <==
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class KvalifikaSdk extends StatefulWidget {
  static const MethodChannel _channel = const MethodChannel('kvalifika_sdk');

  /// Calls this function when SDK initializes
  final Function(BuildContext context) onInitialize;

  /// Calls this function with session id when verification started
  final Function(BuildContext context, String sessionId) onStart;

  /// Calls this function with session id  when verification finished
  final Function(BuildContext context, String sessionId) onFinish;

  /// Calls this function with error and message if there is error. Maybe user cancelled verification or there is some internal error
  final Function(BuildContext context, KvalifikaSdkError error, String message)
      onError;

  final Widget Function(BuildContext context, KvalifikaSdk sdk) builder;

  /// Kvalifika App Id
  final String appId;

  /// Sets Language which SDK will use
  final KvalifikaSdkLocale locale;

  /// Pass filename. Displays custom logo
  final String? logo;

  /// Pass filename. Displays custom document icon
  final String? documentIcon;

  /// Uses custom cancel icon at top left corner
  final String? cancelIcon;

  /// Uses custom active flash icon at top right corner when scanning document
  final String? activeFlashIcon;

  /// Uses custom inactive flash icon at top right corner when scanning document
  final String? inactiveFlashIcon;

  /// Runs SDK in development mode. This is only for developers
  final bool? development;

  const KvalifikaSdk({
    required this.builder,
    required this.appId,
    required this.onInitialize,
    required this.onStart,
    required this.onFinish,
    required this.onError,
    this.locale = KvalifikaSdkLocale.EN,
    this.logo = "",
    this.documentIcon = "",
    this.cancelIcon = "",
    this.activeFlashIcon = "",
    this.inactiveFlashIcon = "",
    this.development = false,
  });

  /// Starts Kvalifika verification session
  void startSession() async {
    await _channel.invokeMethod('sdkStartSession');
  }

  void setMethodHandler(BuildContext context) {
    _channel.setMethodCallHandler((MethodCall call) async {
      if (call.method == "sdkOnInitialize") {
        this.onInitialize(context);
      } else if (call.method == "sdkOnStart") {
        this.onStart(context, call.arguments);
      } else if (call.method == "sdkOnFinish") {
        this.onFinish(context, call.arguments);
      } else if (call.method == "sdkOnError") {
        List args = call.arguments.split("___");
        String errorName = args[0];
        String message = args[1];

        switch (errorName) {
          case 'INVALID_APP_ID':
            this.onError(context, KvalifikaSdkError.INVALID_APP_ID, message);
            break;
          case 'USER_CANCELLED':
            this.onError(context, KvalifikaSdkError.USER_CANCELLED, message);
            break;
          case 'TIMEOUT':
            this.onError(context, KvalifikaSdkError.TIMEOUT, message);
            break;
          case 'SESSION_UNSUCCESSFUL':
            this.onError(
                context, KvalifikaSdkError.SESSION_UNSUCCESSFUL, message);
            break;
          case 'ID_UNSUCCESSFUL':
            this.onError(context, KvalifikaSdkError.ID_UNSUCCESSFUL, message);
            break;
          case 'CAMERA_PERMISSION_DENIED':
            this.onError(
                context, KvalifikaSdkError.CAMERA_PERMISSION_DENIED, message);
            break;
          case 'LANDSCAPE_MODE_NOT_ALLOWED':
            this.onError(
                context, KvalifikaSdkError.LANDSCAPE_MODE_NOT_ALLOWED, message);
            break;
          case 'REVERSE_PORTRAIT_NOT_ALLOWED':
            this.onError(context,
                KvalifikaSdkError.REVERSE_PORTRAIT_NOT_ALLOWED, message);
            break;
          case 'FACE_IMAGES_UPLOAD_FAILED':
            this.onError(
                context, KvalifikaSdkError.FACE_IMAGES_UPLOAD_FAILED, message);
            break;
          case 'DOCUMENT_IMAGES_UPLOAD_FAILED':
            this.onError(context,
                KvalifikaSdkError.DOCUMENT_IMAGES_UPLOAD_FAILED, message);
            break;
          case 'COMPARE_IMAGES_FAILED':
            this.onError(
                context, KvalifikaSdkError.COMPARE_IMAGES_FAILED, message);
            break;
          case 'UNKNOWN_INTERNAL_ERROR':
            this.onError(
                context, KvalifikaSdkError.UNKNOWN_INTERNAL_ERROR, message);
            break;
          default:
            this.onError(
                context, KvalifikaSdkError.UNKNOWN_INTERNAL_ERROR, message);
            break;
        }
      }

      return null;
    });
  }

  void initialize() {
    _channel.invokeMethod('sdkInitialize', {
      'appId': appId,
      'locale': locale.toString().split('.')[1],
      'logo': logo,
      'documentIcon': documentIcon,
      'cancelIcon': cancelIcon,
      'activeFlashIcon': activeFlashIcon,
      'inactiveFlashIcon': inactiveFlashIcon,
      'development': development,
    });
  }

  @override
  _KvalifikaSdkState createState() => _KvalifikaSdkState();
}

class _KvalifikaSdkState extends State<KvalifikaSdk> {
  @override
  void initState() {
    widget.initialize();
    super.initState();
  }

  @override
  void didUpdateWidget(covariant KvalifikaSdk oldWidget) {
    if (widget.locale != oldWidget.locale) {
      widget.initialize();
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    widget.setMethodHandler(context);
    return this.widget.builder(context, this.widget);
  }
}

enum KvalifikaSdkError {
  INVALID_APP_ID,
  USER_CANCELLED,
  TIMEOUT,
  SESSION_UNSUCCESSFUL,
  ID_UNSUCCESSFUL,
  CAMERA_PERMISSION_DENIED,
  LANDSCAPE_MODE_NOT_ALLOWED,
  REVERSE_PORTRAIT_NOT_ALLOWED,
  FACE_IMAGES_UPLOAD_FAILED,
  DOCUMENT_IMAGES_UPLOAD_FAILED,
  COMPARE_IMAGES_FAILED,
  UNKNOWN_INTERNAL_ERROR,
}

enum KvalifikaSdkLocale {
  EN,
  GE,
}
